Port Status

| Port | Port Description | Port Status | Speed | Linked Speed | Flow Control | Max MTU
| 1 |  | Down | Auto | No Speed | Disable | 10240
| 2 |  | Down | Auto | No Speed | Disable | 10240
| 3 | Ceiling Projector | Up | Auto | 100M Full | Disable | 10240
| 4 | Work Laptop | Up | Auto | 1000M Full | Disable | 10240
| 5 | Mediaserver Backup | Up | Auto | 1000M Full | Disable | 10240
| 6 |  | Down | Auto | No Speed | Disable | 10240
| 7 | APC Smart UPS | Up | Auto | 100M Half | Disable | 10240
| 8 | S. SHOP Uplink | Up | Auto | 1000M Full | Disable | 10240
| 9 | WHITEHOT | Up | Auto | 2.5G Full | Disable | 10240
| 10 | HOUSE Uplink | Up | Auto | 5G Full | Disable | 10240